@@ -73,7 +73,7 @@ def print(*args, error=False, warn=False, highlight=False, color="", input=False
 # === END print ===
 
 # === START plot ===
-def plot(y=None, x=None, yerr=None, xerr=None, type=None, xlabel='x', ylabel='y', label=None, marker=None, linestyle=None, linewidth=None,
+def plot(y=None, x=None, yerr=None, xerr=None, type=None, xlabel='x', ylabel='y', label=None, marker=None, linestyle=None, linewidth=None, aspect=None,
          show=False, pause=None, xlog=False, ylog=False, xlim=None, ylim=None, save=None, legend_loc='upper left', text=None, shaded_err=None, *args, **kwargs):
     import matplotlib.pyplot as plt
     if linestyle == 'long dashed': linestyle = (0,(5,5))
@@ -89,7 +89,10 @@ def plot(y=None, x=None, yerr=None, xerr=None, type=None, xlabel='x', ylabel='y'
                 xerr_bars = None; yerr_bars = None
             else:
                 xerr_bars = xerr; yerr_bars = yerr
-            plt.errorbar(x, y, xerr=xerr_bars, yerr=yerr_bars, marker=marker, linestyle=linestyle, linewidth=linewidth, label=label, *args, **kwargs)
+            if type == 'scatter':
+                plt.scatter(x, y, marker=marker, linestyle=linestyle, linewidth=linewidth, label=label, *args, **kwargs)
+            else:
+                plt.errorbar(x, y, xerr=xerr_bars, yerr=yerr_bars, marker=marker, linestyle=linestyle, linewidth=linewidth, label=label, *args, **kwargs)
             if shaded_err is not None: # yerr must have shape (2,N), containing the lower and upper errors for each of the N data points
                 if isinstance(shaded_err, list): # user provided a list with [color, alpha]
                     color_err = shaded_err[1]
@@ -106,6 +109,8 @@ def plot(y=None, x=None, yerr=None, xerr=None, type=None, xlabel='x', ylabel='y'
         if ylim is not None: plt.ylim(ylim)
         if xlog: ax.set_xscale('log')
         if ylog: ax.set_yscale('log')
+        if aspect is not None:
+            ax.set_aspect(aspect)
         legend_handles, legend_labels = ax.get_legend_handles_labels()
         if legend_labels or legend_handles: plt.legend(loc=legend_loc, *args, **kwargs)
         if save:
